@@ -64,6 +64,8 @@ class Akinator():
             progression=progression.json()
             if progression["completion"]=="KO":
                 raise AkinatorError("completion : KO")
+            elif progression["completion"]=="SOUNDLIKE":
+                raise AkinatorError("completion : SOUNDLIKE")
             try:
                 self.json["step"]=int(progression["step"])
                 self.json["progression"]=float(progression["progression"])
